@@ -1,8 +1,8 @@
 ;; About the package
 (define *name* "Guile Library")
 (define *description* "Common modules for Guile Scheme")
-(define *version* "0.2.8")
-(define *updated* "March 2024")
+(define *version* "0.2.8.1")
+(define *updated* "April 2024")
 (define *authors*
   '(("Andreas Rottmann" . "rotty at debian dot org")
     ("Andy Wingo" . "wingo at pobox dot com")
